import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class AbstractGender(BasicComicModule):
    latestUrl = 'http://www.abstractgender.com/'
    imageUrl = 'http://www.abstractgender.com/?comic=%s'
    imageSearch = re.compile(r'<img[^>]+src="(comics/\d+\.\w+)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a\W+href="(\?comic=\d+)"><img[^>]+id="comic_menu_prev"', re.IGNORECASE)
    help = 'Index format: n (unpadded)'
